==> jquery-formatdatetime-1.1.1.tgz: jquery-formatdatetime/README.md <==
# Installation
> `npm install --save @types/jquery-formatdatetime`

# Summary
This package contains type definitions for JQuery formatDateTime (https://github.com/agschwender/jquery.formatDateTime).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/jquery-formatdatetime.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/jquery-formatdatetime/index.d.ts)
````ts
// Type definitions for JQuery formatDateTime 1.1
// Project: https://github.com/agschwender/jquery.formatDateTime
// Definitions by: Anderson Friaça <https://github.com/AndersonFriaca>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped
// TypeScript Version: 2.3

/// <reference types="jquery" />

export type Options = Partial<{
    /**
     * Names of the months, e.g. January
     */
    monthNames: string[];

    /**
     * Shortened names of the months, e.g. Jan
     */
    monthNamesShort: string[];

    /**
     * Names of the days, e.g. Sunday
     */
    dayNames: string[];

    /**
     * Shortened names of the days, e.g. Sun
     */
    dayNamesShort: string[];

    /**
     * Names of the 12-hour clock periods, e.g. AM
     */
    ampmNames: string[];

    /**
     * Callback to convert number to ordinal suffix, e.g. 1 to st
     */
    getSuffix: (num: number) => string;

    /**
     * Attribute which contains the datetime
     */
    attribute: string;

    /**
     * Attribute which contains the datetime format
     */
    formatAttribute: string;

    /**
     * Render dates in UTC instead of local timezone
     */
    utc: boolean;
}>;

declare global {
    interface JQuery {
        formatDateTime(format: string, options?: Options): JQuery;
    }

    interface JQueryStatic {
        formatDateTime(format: string, date: Date, options?: Options): string;
    }
}

````

### Additional Details
 * Last updated: Fri, 15 Sep 2023 20:36:37 GMT
 * Dependencies: [@types/jquery](https://npmjs.com/package/@types/jquery)
 * Global values: none

# Credits
These definitions were written by [Anderson Friaça](https://github.com/AndersonFriaca).

==> jquery-formatdatetime-1.1.2.tgz: jquery-formatdatetime/README.md <==
# Installation
> `npm install --save @types/jquery-formatdatetime`

# Summary
This package contains type definitions for jquery-formatdatetime (https://github.com/agschwender/jquery.formatDateTime).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/jquery-formatdatetime.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/jquery-formatdatetime/index.d.ts)
````ts
/// <reference types="jquery" />

export type Options = Partial<{
    /**
     * Names of the months, e.g. January
     */
    monthNames: string[];

    /**
     * Shortened names of the months, e.g. Jan
     */
    monthNamesShort: string[];

    /**
     * Names of the days, e.g. Sunday
     */
    dayNames: string[];

    /**
     * Shortened names of the days, e.g. Sun
     */
    dayNamesShort: string[];

    /**
     * Names of the 12-hour clock periods, e.g. AM
     */
    ampmNames: string[];

    /**
     * Callback to convert number to ordinal suffix, e.g. 1 to st
     */
    getSuffix: (num: number) => string;

    /**
     * Attribute which contains the datetime
     */
    attribute: string;

    /**
     * Attribute which contains the datetime format
     */
    formatAttribute: string;

    /**
     * Render dates in UTC instead of local timezone
     */
    utc: boolean;
}>;

declare global {
    interface JQuery {
        formatDateTime(format: string, options?: Options): JQuery;
    }

    interface JQueryStatic {
        formatDateTime(format: string, date: Date, options?: Options): string;
    }
}

````

### Additional Details
 * Last updated: Wed, 18 Oct 2023 05:47:07 GMT
 * Dependencies: [@types/jquery](https://npmjs.com/package/@types/jquery)

# Credits
These definitions were written by [Anderson Friaça](https://github.com/AndersonFriaca).
